Contrib
*******

This package provides support for the following BalderHub projects:

BalderHub Project ``balderhub-html``
====================================

Pages
-----

.. autoclass:: balderhub.auth.contrib.html.pages.LoginPage
    :members:


Setup Features
--------------

.. autoclass:: balderhub.auth.contrib.html.setup_features.UserLoginFeature
    :members:
